@@ -1669,6 +1669,16 @@ class Measurement():
             for it, line in enumerate(f):
                 if data_header in line:
                     header_line = it + 1
+        # If data_pointer is not present, raise and error.
+        try:
+            header_line
+        except UnboundLocalError:
+            print(
+                    '\n    ***Error*** \n',
+                    '    --data_pointer "{}"'.format(data_header),
+                    'is not present in {}\n'.format(file)
+                    )
+            exit()
 
         # Columns to extract from file - n.b. these are ordered
         cols = [header_indices[gen] for gen in HEADERS_GENERIC]
