@@ -222,14 +222,16 @@ def ac_mode_func(args):
         if isinstance(models[0], ac.TwoMaximaModel):
             print('\n    ***Warning***:\n')
             print(
-                'Two distinct relaxation processes',
+                '    Two distinct relaxation processes',
                 ' detected in: {}'.format(
                     fit_filename
                 )
             )
             print(
-                '\n    Prepare two separate files for each process',
-                ' and run RelaxationProfile --AC Generalised '
+                '\n    Prepare two separate files for each process and then,',
+                'on each file, run ccfit2 relaxation <filename> \n',
+                '\n    See the manual for the expected format of relaxation',
+                'input files.'
             )
             exit()
 
