@@ -430,8 +430,10 @@ class Process_Waveform():
             ax3 = ax1.twinx()
             ax4 = ax2.twinx()
 
+            
+
             # Refer the time to first point within each set.
-            time = time[i]-time[i][0]
+            _time = time[i]-time[i][0]
 
             # Get only the positive values of the fourier transforms.
             pos_indx = np.where(freq[i] > 0.)
@@ -439,8 +441,8 @@ class Process_Waveform():
             # pos_indx = freq[1:len(time)/2]
 
             # Plot the data.
-            ax1.plot(time, field[i], lw=1.5, c='k', label='field')
-            ax3.plot(time, moment[i], lw=1.5, c='tab:blue', label='moment')
+            ax1.plot(_time, field[i], lw=1.5, c='k', label='field')
+            ax3.plot(_time, moment[i], lw=1.5, c='tab:blue', label='moment')
             ax2.plot(
                 freq[i][pos_indx], np.abs(ft_H[i][pos_indx]),
                 lw=1.5, c='k', label='field')
